==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/P2SVpnServerConfigVpnClientRootCertificateResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * VPN client root certificate of P2SVpnServerConfiguration.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property provisioningState The provisioning state of the VPN client root certificate resource.
 * @property publicCertData The certificate public data.
 */
public data class P2SVpnServerConfigVpnClientRootCertificateResponse(
    public val etag: String? = null,
    public val id: String? = null,
    public val name: String? = null,
    public val provisioningState: String,
    public val publicCertData: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.P2SVpnServerConfigVpnClientRootCertificateResponse):
            P2SVpnServerConfigVpnClientRootCertificateResponse =
            P2SVpnServerConfigVpnClientRootCertificateResponse(
                etag = javaType.etag().map({ args0 -> args0 }).orElse(null),
                id = javaType.id().map({ args0 -> args0 }).orElse(null),
                name = javaType.name().map({ args0 -> args0 }).orElse(null),
                provisioningState = javaType.provisioningState(),
                publicCertData = javaType.publicCertData(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/P2SVpnServerConfigVpnClientRootCertificateResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * VPN client root certificate of P2SVpnServerConfiguration.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property provisioningState The provisioning state of the VPN client root certificate resource.
 * @property publicCertData The certificate public data.
 */
public data class P2SVpnServerConfigVpnClientRootCertificateResponse(
    public val etag: String? = null,
    public val id: String? = null,
    public val name: String? = null,
    public val provisioningState: String,
    public val publicCertData: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.P2SVpnServerConfigVpnClientRootCertificateResponse): P2SVpnServerConfigVpnClientRootCertificateResponse =
            P2SVpnServerConfigVpnClientRootCertificateResponse(
                etag = javaType.etag().map({ args0 -> args0 }).orElse(null),
                id = javaType.id().map({ args0 -> args0 }).orElse(null),
                name = javaType.name().map({ args0 -> args0 }).orElse(null),
                provisioningState = javaType.provisioningState(),
                publicCertData = javaType.publicCertData(),
            )
    }
}
